@@ -1,15 +1,6 @@
-extern crate futures_util;
-
-use super::parser::ast::*;
-use super::println_on_debug;
-use conditionals::Conditionals;
-use cycles::Cycles;
-use futures_util::pin_mut;
-use futures_util::stream::StreamExt;
-use interpreter::Interpreter;
 use std::path::PathBuf;
-use utils::path;
-use utils::Str;
+
+use crate::{parser::ast::*, println_on_debug};
 
 mod conditionals;
 mod cycles;
@@ -20,6 +11,12 @@ mod operators;
 mod utils;
 mod variables;
 
+use conditionals::Conditionals;
+use cycles::Cycles;
+use futures_util::{pin_mut, stream::StreamExt};
+use interpreter::Interpreter;
+use utils::{path, Str};
+
 type AST = super::parser::ast::AST;
 
 pub async fn run(ast: AST, directory: PathBuf, recursive: bool) {
@@ -51,7 +48,7 @@ impl Interpreter {
         for i in 0..self.__ast__.cycles.len() {
             if i == 0 && self.__ast__.cycles.len() <= 1 {}
             // load files
-            let file_generator = path::file_generator(self.clone());
+            let file_generator = path::file_generator(self.to_owned());
             pin_mut!(file_generator);
 
             while let Some(path) = file_generator.next().await {
@@ -60,7 +57,7 @@ impl Interpreter {
                 println_on_debug!("  File [ {} ]", &self.__file__);
 
                 // get cycle
-                let cycle = self.__ast__.cycles[i].clone();
+                let cycle = self.__ast__.cycles[i].to_owned();
 
                 // get if file matches the conditionals
                 if self.eval_conditionals() {
