@@ -1,20 +1,18 @@
-extern crate path_absolutize;
 extern crate md5;
+extern crate path_absolutize;
 extern crate sha256;
 
 use path_absolutize::*;
 use regex::Regex;
 use std::fs;
-use std::io;
-use std::path::Path;
-pub use string::Str;
-pub use sum::Sum;
-pub use sum::SumTypes;
 use std::fs::File;
 use std::io::prelude::*;
 use std::panic;
+use std::path::Path;
 use std::process;
-
+pub use string::Str;
+pub use sum::Sum;
+pub use sum::SumTypes;
 
 pub mod path;
 pub mod regexp;
@@ -29,7 +27,7 @@ impl path::Path for super::Interpreter {
 
         // create a new path struct with the
         // absolute path and get if exists
-        return Path::new(&path).exists();
+        Path::new(&path).exists()
     }
 
     fn absolutize(&self, input: &String) -> String {
@@ -41,12 +39,10 @@ impl path::Path for super::Interpreter {
         let path = p.to_str().unwrap();
 
         // return it converted to String
-        return path.to_string();
+        path.to_string()
     }
 
     fn is_file(&self, input: &String) -> Result<bool, ()> {
-        let metadata: io::Result<fs::Metadata> = fs::metadata(input);
-
         // maybe file was delete in previous cycles.
         // if the path just was wrong, its not my fault,
         // user's fault. just re-run voila but reading what
@@ -55,14 +51,9 @@ impl path::Path for super::Interpreter {
         // doing a hashmap of stuff deleted and then a checker,
         // enough overhead & bottlenecks with the async hell
         // of the cycles & the interpreter
-        match metadata {
-            Err(_) => return Err(()),
-            _ => {
-                return match metadata {
-                    Ok(md) => Ok(md.is_file()),
-                    Err(_) => Err(()),
-                }
-            }
+        match fs::metadata(input) {
+            Ok(md) => Ok(md.is_file()),
+            Err(_) => Err(()),
         }
     }
 }
@@ -73,26 +64,13 @@ impl regexp::RegExp for super::Interpreter {
         let regex = Regex::new(&regexp).unwrap();
 
         // return an eval of the regex with the string
-        return regex.is_match(&input);
+        regex.is_match(&input)
     }
 }
 
 impl Str for super::Interpreter {
     fn trim_spaces(&self, str: &String) -> String {
-        // get chars
-        let mut str_chars = str.chars();
-
-        // remove leading spaces
-        if str.starts_with(" ") {
-            str_chars.next();
-        }
-
-        // remove ending spaces
-        if str.ends_with(" ") {
-            str_chars.next_back();
-        }
-
-        return String::from(str_chars.as_str());
+        str.trim().to_string()
     }
 }
 
@@ -100,20 +78,14 @@ impl Sum for super::Interpreter {
     fn get_sum_of(&self, file: &String, sum: SumTypes) -> Result<String, String> {
         let bytes = self.read_bytes_of_file(file);
         println!("{:?}", sum);
-        if sum == SumTypes::Sha256 {
-            println!("sha256");
-            return Ok(sha256::digest_bytes(bytes));
-        } else {
-            println!("md5");
-            return Ok(format!("{:x}", md5::compute(bytes)));
+        match sum {
+            SumTypes::Sha256 => Ok(sha256::digest_bytes(bytes)),
+            SumTypes::Md5 => Ok(format!("{:x}", md5::compute(bytes))),
         }
     }
-    
     fn read_bytes_of_file<'a>(&self, path: &String) -> &'a [u8] {
         let buffer = "";
-        let file = panic::catch_unwind(|| {
-            return File::open(path).unwrap();
-        });
+        let file = panic::catch_unwind(|| File::open(path).unwrap());
         match file {
             Ok(mut f) => f
                 .read_to_string(&mut String::from(buffer))
@@ -126,6 +98,6 @@ impl Sum for super::Interpreter {
                 process::exit(1)
             }
         };
-        return buffer.as_bytes();
+        buffer.as_bytes()
     }
-}
\ No newline at end of file
+}
